/****************************************************************************
** Meta object code from reading C++ file 'UISession.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.10.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../src/VBox/Frontends/VirtualBox/src/runtime/UISession.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'UISession.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.10.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9UISessionE_t {};
} // unnamed namespace

template <> constexpr inline auto UISession::qt_create_metaobjectdata<qt_meta_tag_ZN9UISessionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "UISession",
        "sigAdditionsStateChange",
        "",
        "sigAdditionsStateActualChange",
        "sigAudioAdapterChange",
        "sigClipboardModeChange",
        "KClipboardMode",
        "enmMode",
        "sigCPUExecutionCapChange",
        "sigDnDModeChange",
        "KDnDMode",
        "sigGuestMonitorChange",
        "KGuestMonitorChangedEventType",
        "enmChangeType",
        "uScreenId",
        "QRect",
        "screenGeo",
        "sigMachineStateChange",
        "sigMediumChange",
        "CMediumAttachment",
        "comMediumAttachment",
        "sigNetworkAdapterChange",
        "CNetworkAdapter",
        "comNetworkAdapter",
        "sigRecordingChange",
        "sigSharedFolderChange",
        "sigStorageDeviceChange",
        "comAttachment",
        "fRemoved",
        "fSilent",
        "sigUSBControllerChange",
        "sigUSBDeviceStateChange",
        "CUSBDevice",
        "comDevice",
        "fAttached",
        "CVirtualBoxErrorInfo",
        "comError",
        "sigVRDEChange",
        "sigRuntimeError",
        "fFatal",
        "strErrorId",
        "strMessage",
        "sigKeyboardLedsChange",
        "fNumLock",
        "fCapsLock",
        "fScrollLock",
        "sigMousePointerShapeChange",
        "UIMousePointerShapeData",
        "shapeData",
        "sigMouseCapabilityChange",
        "fSupportsAbsolute",
        "fSupportsRelative",
        "fSupportsTouchScreen",
        "fSupportsTouchPad",
        "fNeedsHostCursor",
        "sigCursorPositionChange",
        "fContainsData",
        "uX",
        "uY",
        "sltInstallGuestAdditionsFrom",
        "strSource",
        "sltMountDVDAdHoc",
        "sltDetachCOM",
        "sltStateChange",
        "KMachineState",
        "enmState",
        "sltAdditionsChange",
        "sltClipboardError",
        "strMsg",
        "sltHandleMachineStateSaved",
        "fSuccess",
        "sltHandleMachinePoweredOff",
        "fIncludingDiscard",
        "sltHandleSnapshotRestored"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sigAdditionsStateChange'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigAdditionsStateActualChange'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigAudioAdapterChange'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigClipboardModeChange'
        QtMocHelpers::SignalData<void(KClipboardMode)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'sigCPUExecutionCapChange'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigDnDModeChange'
        QtMocHelpers::SignalData<void(KDnDMode)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 7 },
        }}),
        // Signal 'sigGuestMonitorChange'
        QtMocHelpers::SignalData<void(KGuestMonitorChangedEventType, ulong, QRect)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { QMetaType::ULong, 14 }, { 0x80000000 | 15, 16 },
        }}),
        // Signal 'sigMachineStateChange'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigMediumChange'
        QtMocHelpers::SignalData<void(const CMediumAttachment &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Signal 'sigNetworkAdapterChange'
        QtMocHelpers::SignalData<void(const CNetworkAdapter &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Signal 'sigRecordingChange'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigSharedFolderChange'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigStorageDeviceChange'
        QtMocHelpers::SignalData<void(const CMediumAttachment &, bool, bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 27 }, { QMetaType::Bool, 28 }, { QMetaType::Bool, 29 },
        }}),
        // Signal 'sigUSBControllerChange'
        QtMocHelpers::SignalData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigUSBDeviceStateChange'
        QtMocHelpers::SignalData<void(const CUSBDevice &, bool, const CVirtualBoxErrorInfo &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 }, { QMetaType::Bool, 34 }, { 0x80000000 | 35, 36 },
        }}),
        // Signal 'sigVRDEChange'
        QtMocHelpers::SignalData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sigRuntimeError'
        QtMocHelpers::SignalData<void(bool, const QString &, const QString &)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 39 }, { QMetaType::QString, 40 }, { QMetaType::QString, 41 },
        }}),
        // Signal 'sigKeyboardLedsChange'
        QtMocHelpers::SignalData<void(bool, bool, bool)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 43 }, { QMetaType::Bool, 44 }, { QMetaType::Bool, 45 },
        }}),
        // Signal 'sigMousePointerShapeChange'
        QtMocHelpers::SignalData<void(const UIMousePointerShapeData &)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 47, 48 },
        }}),
        // Signal 'sigMouseCapabilityChange'
        QtMocHelpers::SignalData<void(bool, bool, bool, bool, bool)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 50 }, { QMetaType::Bool, 51 }, { QMetaType::Bool, 52 }, { QMetaType::Bool, 53 },
            { QMetaType::Bool, 54 },
        }}),
        // Signal 'sigCursorPositionChange'
        QtMocHelpers::SignalData<void(bool, unsigned long, unsigned long)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 56 }, { QMetaType::ULong, 57 }, { QMetaType::ULong, 58 },
        }}),
        // Slot 'sltInstallGuestAdditionsFrom'
        QtMocHelpers::SlotData<void(const QString &)>(59, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 60 },
        }}),
        // Slot 'sltMountDVDAdHoc'
        QtMocHelpers::SlotData<void(const QString &)>(61, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 60 },
        }}),
        // Slot 'sltDetachCOM'
        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sltStateChange'
        QtMocHelpers::SlotData<void(KMachineState)>(63, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 64, 65 },
        }}),
        // Slot 'sltAdditionsChange'
        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sltClipboardError'
        QtMocHelpers::SlotData<void(const QString &)>(67, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 68 },
        }}),
        // Slot 'sltHandleMachineStateSaved'
        QtMocHelpers::SlotData<void(bool)>(69, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 70 },
        }}),
        // Slot 'sltHandleMachinePoweredOff'
        QtMocHelpers::SlotData<void(bool, bool)>(71, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 70 }, { QMetaType::Bool, 72 },
        }}),
        // Slot 'sltHandleSnapshotRestored'
        QtMocHelpers::SlotData<void(bool)>(73, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 70 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<UISession, qt_meta_tag_ZN9UISessionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject UISession::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9UISessionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9UISessionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9UISessionE_t>.metaTypes,
    nullptr
} };

void UISession::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<UISession *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sigAdditionsStateChange(); break;
        case 1: _t->sigAdditionsStateActualChange(); break;
        case 2: _t->sigAudioAdapterChange(); break;
        case 3: _t->sigClipboardModeChange((*reinterpret_cast<std::add_pointer_t<KClipboardMode>>(_a[1]))); break;
        case 4: _t->sigCPUExecutionCapChange(); break;
        case 5: _t->sigDnDModeChange((*reinterpret_cast<std::add_pointer_t<KDnDMode>>(_a[1]))); break;
        case 6: _t->sigGuestMonitorChange((*reinterpret_cast<std::add_pointer_t<KGuestMonitorChangedEventType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QRect>>(_a[3]))); break;
        case 7: _t->sigMachineStateChange(); break;
        case 8: _t->sigMediumChange((*reinterpret_cast<std::add_pointer_t<CMediumAttachment>>(_a[1]))); break;
        case 9: _t->sigNetworkAdapterChange((*reinterpret_cast<std::add_pointer_t<CNetworkAdapter>>(_a[1]))); break;
        case 10: _t->sigRecordingChange(); break;
        case 11: _t->sigSharedFolderChange(); break;
        case 12: _t->sigStorageDeviceChange((*reinterpret_cast<std::add_pointer_t<CMediumAttachment>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 13: _t->sigUSBControllerChange(); break;
        case 14: _t->sigUSBDeviceStateChange((*reinterpret_cast<std::add_pointer_t<CUSBDevice>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<CVirtualBoxErrorInfo>>(_a[3]))); break;
        case 15: _t->sigVRDEChange(); break;
        case 16: _t->sigRuntimeError((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 17: _t->sigKeyboardLedsChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 18: _t->sigMousePointerShapeChange((*reinterpret_cast<std::add_pointer_t<UIMousePointerShapeData>>(_a[1]))); break;
        case 19: _t->sigMouseCapabilityChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 20: _t->sigCursorPositionChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[3]))); break;
        case 21: _t->sltInstallGuestAdditionsFrom((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 22: _t->sltMountDVDAdHoc((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 23: _t->sltDetachCOM(); break;
        case 24: _t->sltStateChange((*reinterpret_cast<std::add_pointer_t<KMachineState>>(_a[1]))); break;
        case 25: _t->sltAdditionsChange(); break;
        case 26: _t->sltClipboardError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 27: _t->sltHandleMachineStateSaved((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 28: _t->sltHandleMachinePoweredOff((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 29: _t->sltHandleSnapshotRestored((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KClipboardMode >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDnDMode >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KGuestMonitorChangedEventType >(); break;
            }
            break;
        case 18:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< UIMousePointerShapeData >(); break;
            }
            break;
        case 24:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KMachineState >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (UISession::*)()>(_a, &UISession::sigAdditionsStateChange, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (UISession::*)()>(_a, &UISession::sigAdditionsStateActualChange, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (UISession::*)()>(_a, &UISession::sigAudioAdapterChange, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (UISession::*)(KClipboardMode )>(_a, &UISession::sigClipboardModeChange, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (UISession::*)()>(_a, &UISession::sigCPUExecutionCapChange, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (UISession::*)(KDnDMode )>(_a, &UISession::sigDnDModeChange, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (UISession::*)(KGuestMonitorChangedEventType , ulong , QRect )>(_a, &UISession::sigGuestMonitorChange, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (UISession::*)()>(_a, &UISession::sigMachineStateChange, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (UISession::*)(const CMediumAttachment & )>(_a, &UISession::sigMediumChange, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (UISession::*)(const CNetworkAdapter & )>(_a, &UISession::sigNetworkAdapterChange, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (UISession::*)()>(_a, &UISession::sigRecordingChange, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (UISession::*)()>(_a, &UISession::sigSharedFolderChange, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (UISession::*)(const CMediumAttachment & , bool , bool )>(_a, &UISession::sigStorageDeviceChange, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (UISession::*)()>(_a, &UISession::sigUSBControllerChange, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (UISession::*)(const CUSBDevice & , bool , const CVirtualBoxErrorInfo & )>(_a, &UISession::sigUSBDeviceStateChange, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (UISession::*)()>(_a, &UISession::sigVRDEChange, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (UISession::*)(bool , const QString & , const QString & )>(_a, &UISession::sigRuntimeError, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (UISession::*)(bool , bool , bool )>(_a, &UISession::sigKeyboardLedsChange, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (UISession::*)(const UIMousePointerShapeData & )>(_a, &UISession::sigMousePointerShapeChange, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (UISession::*)(bool , bool , bool , bool , bool )>(_a, &UISession::sigMouseCapabilityChange, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (UISession::*)(bool , unsigned long , unsigned long )>(_a, &UISession::sigCursorPositionChange, 20))
            return;
    }
}

const QMetaObject *UISession::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *UISession::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9UISessionE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int UISession::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
    return _id;
}

// SIGNAL 0
void UISession::sigAdditionsStateChange()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void UISession::sigAdditionsStateActualChange()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void UISession::sigAudioAdapterChange()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void UISession::sigClipboardModeChange(KClipboardMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void UISession::sigCPUExecutionCapChange()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void UISession::sigDnDModeChange(KDnDMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void UISession::sigGuestMonitorChange(KGuestMonitorChangedEventType _t1, ulong _t2, QRect _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3);
}

// SIGNAL 7
void UISession::sigMachineStateChange()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void UISession::sigMediumChange(const CMediumAttachment & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void UISession::sigNetworkAdapterChange(const CNetworkAdapter & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void UISession::sigRecordingChange()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void UISession::sigSharedFolderChange()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void UISession::sigStorageDeviceChange(const CMediumAttachment & _t1, bool _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2, _t3);
}

// SIGNAL 13
void UISession::sigUSBControllerChange()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void UISession::sigUSBDeviceStateChange(const CUSBDevice & _t1, bool _t2, const CVirtualBoxErrorInfo & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2, _t3);
}

// SIGNAL 15
void UISession::sigVRDEChange()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void UISession::sigRuntimeError(bool _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1, _t2, _t3);
}

// SIGNAL 17
void UISession::sigKeyboardLedsChange(bool _t1, bool _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1, _t2, _t3);
}

// SIGNAL 18
void UISession::sigMousePointerShapeChange(const UIMousePointerShapeData & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void UISession::sigMouseCapabilityChange(bool _t1, bool _t2, bool _t3, bool _t4, bool _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 20
void UISession::sigCursorPositionChange(bool _t1, unsigned long _t2, unsigned long _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 20, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
